//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Alpha.rc
//
#define IDR_MENU                        101
#define IDR_MENU_SEARCHOPTION           102
#define IDR_ICONS                       111
#define IDB_BMP_LOGO                    153
#define IDR_ICON_NARROWING              154
#define IDC_STATUSBAR                   201
#define IDC_TOOLBAR                     202
#define IDC_DEBUGBAR                    203
#define IDC_BUFFERBAR                   204
#define IDD_DLG_OPENFILE                501
#define IDD_DLG_SAVEFILE                502
#define IDD_DLG_SEARCH                  503
#define IDD_DLG_ABOUT                   505
#define IDD_DLG_CODEPAGES               506
#define IDD_DLG_FILEPROPERTY            508
#define IDD_DLG_FILEOPERATION           509
#define IDD_DLG_GOTOLINE                511
#define IDD_DLG_EXECUTECOMMAND          512
#define IDD_DLG_BOOKMARKS               513
#define IDD_DLG_DEBUGBREAKPOINTS        514
#define IDD_DLG_DEBUGCALLSTACK          515
#define IDD_DLG_DEBUGVARIABLES          516
#define IDD_DLG_DEBUGIMMEDIATE          517
#define IDD_DLG_DEBUGTHREADS            518
#define IDD_DLG_DEBUGEXCEPTION          519
#define IDD_DLG_DEBUGACTIVEDOCUMENTS    520
#define IDD_DLG_SELECTLANGUAGE          522
#define IDD_DLG_CONFIRMUNSAVEDDOCUMENTS 524
#define IDD_DLG_FILENEWWITHFORMAT       525
#define IDD_DLG_ABBREVIATIONS           527
#define IDD_DLG_NEWABBREV               528
#define IDD_DLG_BUFFERLIST              529
#define COMMAND_START                   1000
#define CMD_FILE_NEW                    1000
#define IDC_TAB_VIEWS                   1001
#define CMD_FILE_NEWWITHFORMAT          1001
#define IDC_TAB_VARIABLES               1002
#define CMD_FILE_OPEN                   1002
#define IDC_TAB_KEYWORD                 1003
#define CMD_FILE_CLOSE                  1003
#define IDC_TAB_SEARCHTYPE              1004
#define CMD_FILE_CLOSEALL               1004
#define CMD_FILE_SAVE                   1005
#define CMD_FILE_SAVEAS                 1006
#define CMD_FILE_SAVEALL                1007
#define CMD_FILE_REOPEN                 1008
#define CMD_FILE_REOPENWITHCODEPAGE     1009
#define CMD_FILE_EXIT                   1010
#define CMD_FILE_PROPERTY               1011
#define CMD_FILE_RENAME                 1012
#define CMD_FILE_MOVE                   1013
#define CMD_FILE_COPY                   1014
#define CMD_FILE_DELETE                 1015
#define CMD_FILE_SENDMAIL               1016
#define CMD_FILE_CLOSEOTHERS            1017
#define IDC_COMBO_CHARCODE              1101
#define IDC_COMBO_BREAKCODE             1102
#define IDC_COMBO_FINDWHAT              1103
#define IDC_COMBO_REPLACEWITH           1104
#define IDC_COMBO_COMMAND               1109
#define IDC_COMBO_CALLSTACKS            1111
#define IDC_COMBO_DOCTYPENAMES          1113
#define IDC_COMBO_CASEFOLDING           1118
#define IDC_COMBO_SEARCHTYPE            1119
#define IDC_CHK_WHOLEWORD               1201
#define IDC_CHK_AUTOCLOSE               1202
#define IDC_CHK_AUTOSAVE                1203
#define IDC_CHK_USEREGEXP               1204
#define IDC_CHK_SAVESELECTION           1205
#define IDC_CHK_GETCONSOLE              1206
#define IDC_CHK_USEUNICODEFORINPUT      1207
#define IDC_CHK_SHOWALLFILES            1208
#define IDC_CHK_SHIFT                   1209
#define IDC_CHK_EVALASSTATEMENT         1210
#define IDC_CHK_EVALWITHNOSIDEEFFECTS   1211
#define IDC_CHK_USEHEXADECIMAL          1212
#define IDC_CHK_SIMPLIFIEDTRADITIONAL   1213
#define IDC_CHK_IGNOREPUNCTUATIONS      1214
#define IDC_CHK_IGNORESYMBOLS           1215
#define IDC_CHK_IGNOREWHITESPACES       1216
#define IDC_CHK_IGNOREDIACRITICS        1217
#define IDC_CHK_IGNOREVOWELS            1218
#define IDC_CHK_IGNOREKASHIDA           1219
#define IDC_CHK_IGNORECONTROLS          1220
#define IDC_CHK_ACCENTREMOVAL           1221
#define IDC_CHK_CANONICALDUPLICATESFOLDING 1222
#define IDC_CHK_DASHESFOLDING           1223
#define IDC_CHK_GREEKLETTERFORMSFOLDING 1224
#define IDC_CHK_HEBREWALTERNATESFOLDING 1225
#define IDC_CHK_JAMOFOLDING             1226
#define IDC_CHK_MATHSYMBOLFOLDING       1227
#define IDC_CHK_NATIVEDIGITFOLDING      1228
#define IDC_CHK_NOBREAKFOLDING          1229
#define IDC_CHK_OVERLINEFOLDING         1230
#define IDC_CHK_POSITIONALFORMSFOLDING  1231
#define IDC_CHK_SMALLFORMSFOLDING       1232
#define IDC_CHK_SPACEFOLDING            1233
#define IDC_CHK_SPACINGACCENTS          1234
#define IDC_CHK_SUBSCRIPTFOLDING        1235
#define IDC_CHK_SYMBOLFOLDING           1236
#define IDC_CHK_UNDERLINEFOLDING        1237
#define IDC_CHK_VERTICALFORMSFOLDING    1238
#define IDC_CHK_CIRCLEDSYMBOLSEXPANSION 1239
#define IDC_CHK_DOTTED                  1240
#define IDC_CHK_ELLIPSISEXPANSION       1241
#define IDC_CHK_FRACTIONEXPANSION       1242
#define IDC_CHK_INTEGRALEXPANSION       1243
#define IDC_CHK_LIGATUREEXPANSIONMISC   1244
#define IDC_CHK_PARENTHESIZED           1245
#define IDC_CHK_PRIMESEXPANSION         1246
#define IDC_CHK_ROMANNUMERALS           1247
#define IDC_CHK_SQUARED                 1248
#define IDC_CHK_SQUAREDUNMARKED         1249
#define IDC_CHK_DIGRAPHS                1250
#define IDC_CHK_OTHERMULTIGRAPHS        1251
#define IDC_CHK_DIACRITICREMOVAL        1252
#define IDC_CHK_HANRADICALFOLDING       1253
#define IDC_CHK_KANAFOLDING             1254
#define IDC_CHK_LETTERFORMSFOLDING      1255
#define IDC_CHK_SIMPLIFIEDHANFOLDING    1256
#define IDC_CHK_SUPERSCRIPTFOLDING      1257
#define IDC_CHK_SUZHOUNUMERALFOLDING    1258
#define IDC_CHK_WIDTHFOLDING            1259
#define IDC_RADIO_SELECTION             1301
#define IDC_RADIO_WHOLEFILE             1302
#define IDC_RADIO_SHARE                 1303
#define IDC_RADIO_DENYWRITE             1304
#define IDC_RADIO_DENYREADWRITE         1305
#define IDC_RADIO_LOGICALLINE           1306
#define IDC_RADIO_PHYSICALLINE          1307
#define IDC_RADIO_USEDEFAULT            1308
#define IDC_RADIO_USEPREVIOUS           1309
#define IDC_RADIO_USESPECIFIED          1310
#define IDC_RADIO_UNDOUNLIMITED         1311
#define IDC_RADIO_UNDOLIMITEDSPECIFIED  1312
#define IDC_RADIO_SYSTEMACP             1313
#define IDC_RADIO_CUSTOMCP              1314
#define IDC_RADIO_STOP                  1315
#define IDC_RADIO_IGNORE                1316
#define IDC_RADIO_NOAUTOINDENT          1317
#define IDC_RADIO_BLOCKINDENT           1318
#define IDC_RADIO_SMARTINDENT           1319
#define IDC_RADIO_IGNORECASE_NO         1320
#define IDC_RADIO_IGNORECASE_ASCII      1321
#define IDC_RADIO_IGNORECASE_SIMPLE     1322
#define IDC_RADIO_IGNORECASE_FULL       1323
#define IDC_LINK_HOMEPAGE               1401
#define IDC_LINK_SELECTALL              1402
#define IDC_LINK_CLEARALL               1403
#define IDC_LINK_SOURCEFORGE            1404
#define IDC_BTN_RESET                   1501
#define IDC_BTN_BROWSE                  1502
#define IDC_BTN_ADD                     1503
#define IDC_BTN_DELETE                  1504
#define IDC_BTN_USESYSTEM               1507
#define IDC_BTN_JUMP                    1509
#define IDC_BTN_UPDATE                  1510
#define IDC_BTN_CLEAR                   1511
#define IDC_BTN_SUSPEND                 1512
#define IDC_BTN_RESUME                  1513
#define IDC_BTN_BOOKMARKALL             1514
#define IDC_BTN_SAVEALL                 1515
#define IDC_BTN_NOSAVEALL               1516
#define IDC_EDIT_INTERVAL               1602
#define IDC_EDIT_CHARSPACE              1608
#define IDC_EDIT_FILENAME               1616
#define IDC_EDIT_DESTPATH               1617
#define IDC_EDIT_LINENUMBER             1618
#define IDC_EDIT_INPUT                  1619
#define IDC_EDIT_OUTPUT                 1620
#define IDC_EDIT_BOUNDCOMMAND           1621
#define IDC_EDIT_BOUNDKEY               1622
#define IDC_EDIT_CHARSTREATEDASALPHA    1623
#define IDC_SPIN_MRULIMIT               1701
#define IDC_SPIN_INTERVAL               1702
#define IDC_SPIN_LEFTMARGIN             1703
#define IDC_SPIN_TOPMARGIN              1704
#define IDC_SPIN_LINESPACE              1705
#define IDC_SPIN_CHARSPACE              1706
#define IDC_SPIN_TABWIDTH               1707
#define IDC_SPIN_LINENUMBER             1708
#define IDC_SPIN_WINDOWLEFT             1709
#define IDC_SPIN_WINDOWTOP              1710
#define IDC_SPIN_WINDOWWIDTH            1711
#define IDC_SPIN_WINDOWHEIGHT           1712
#define IDC_SPIN_UNDOLIMIT              1713
#define IDC_STATIC_1                    1801
#define IDC_STATIC_2                    1802
#define IDC_STATIC_3                    1803
#define IDC_STATIC_4                    1804
#define IDC_STATIC_5                    1805
#define IDC_STATIC_INTERVAL1            1806
#define IDC_STATIC_INTERVAL2            1807
#define IDC_STATIC_MRULIMIT             1808
#define IDC_STATIC_PROMPT               1809
#define CMD_FILE_TOP                    1900
#define IDC_LIST_CODEPAGES              1901
#define CMD_FILE_MRU                    1901
#define IDC_LIST_COLORS                 1902
#define CMD_FILE_OPERATE                1902
#define IDC_LIST_KEYWORDS1              1903
#define IDC_LIST_KEYWORDS2              1904
#define IDC_LIST_BOOKMARKS              1905
#define IDC_LIST_KEYS                   1906
#define IDC_LIST_SCRIPTENGINES          1907
#define IDC_LIST_DEBUGTHREADS           1908
#define IDC_LIST_DEBUGAPPLICATIONS      1909
#define IDC_LIST_DEBUGSTACKFRAMES       1910
#define IDC_LIST_PROPERTIES             1911
#define IDC_LIST_BREAKPOINTS            1912
#define IDC_LIST_EXCEPTIONS             1913
#define IDC_LIST_GLOBALVARIABLES        1914
#define IDC_LIST_LOCALVARIABLES         1915
#define IDC_LIST_WATCH                  1916
#define IDC_LIST_AUTOCOMPLETE           1917
#define IDC_LIST_DOCUMENTS              1918
#define IDC_LIST_ABBREVIATIONS          1919
#define CMD_EDIT_DELETE                 2000
#define IDC_TREE_OUTLINE                2001
#define CMD_EDIT_BACKSPACE              2001
#define IDC_TREE_COMMANDS               2002
#define CMD_EDIT_DELETETONEXTWORD       2002
#define IDC_TREE_ACTIVEDOCUMENTS        2003
#define CMD_EDIT_DELETETOPREVWORD       2003
#define CMD_EDIT_DELETELINE             2004
#define CMD_EDIT_INSERTPREVLINE         2005
#define CMD_EDIT_BREAK                  2006
#define CMD_EDIT_UNDO                   2007
#define CMD_EDIT_REDO                   2008
#define CMD_EDIT_CUT                    2009
#define CMD_EDIT_COPY                   2010
#define CMD_EDIT_PASTE                  2011
#define CMD_EDIT_INSERTTAB              2012
#define CMD_EDIT_DELETETAB              2013
#define CMD_EDIT_TABIFY                 2014
#define CMD_EDIT_UNTABIFY               2015
#define CMD_EDIT_CHARTOCODEPOINT        2016
#define CMD_EDIT_CODEPOINTTOCHAR        2017
#define CMD_EDIT_MAKENEXTGRAVE          2018
#define CMD_EDIT_MAKENEXTACUTE          2019
#define CMD_EDIT_MAKENEXTCIRCUMFLEX     2020
#define CMD_EDIT_MAKENEXTTILDE          2021
#define CMD_EDIT_MAKENEXTDIAERESIS      2022
#define CMD_EDIT_MAKENEXTCEDILLA        2023
#define CMD_EDIT_RECOMPOSE              2024
#define CMD_EDIT_TOGGLEOVERTYPEMODE     2025
#define CMD_EDIT_OPENCANDIDATEWINDOW    2026
#define CMD_EDIT_HOME                   2027
#define CMD_EDIT_END                    2028
#define CMD_EDIT_LINEHOME               2029
#define CMD_EDIT_LINEEND                2030
#define CMD_EDIT_CHARNEXT               2031
#define CMD_EDIT_CHARPREV               2032
#define CMD_EDIT_WORDENDNEXT            2033
#define CMD_EDIT_WORDENDPREV            2034
#define CMD_EDIT_WORDNEXT               2035
#define CMD_EDIT_WORDPREV               2036
#define CMD_EDIT_LINEDOWN               2037
#define CMD_EDIT_LINEUP                 2038
#define CMD_EDIT_PAGEDOWN               2039
#define CMD_EDIT_PAGEUP                 2040
#define CMD_EDIT_HOMEEXTEND             2041
#define CMD_EDIT_ENDEXTEND              2042
#define CMD_EDIT_LINEHOMEEXTEND         2043
#define CMD_EDIT_LINEENDEXTEND          2044
#define CMD_EDIT_CHARNEXTEXTEND         2045
#define CMD_EDIT_CHARPREVEXTEND         2046
#define CMD_EDIT_WORDENDNEXTEXTEND      2047
#define CMD_EDIT_WORDENDPREVEXTEND      2048
#define CMD_EDIT_WORDNEXTEXTEND         2049
#define CMD_EDIT_WORDPREVEXTEND         2050
#define CMD_EDIT_LINEDOWNEXTEND         2051
#define CMD_EDIT_LINEUPEXTEND           2052
#define CMD_EDIT_PAGEDOWNEXTEND         2053
#define CMD_EDIT_PAGEUPEXTEND           2054
#define CMD_EDIT_SELECTALL              2055
#define CMD_EDIT_SELECTCURRENTWORD      2056
#define CMD_EDIT_CANCELSELECTION        2057
#define CMD_EDIT_SCROLLHOME             2058
#define CMD_EDIT_SCROLLEND              2059
#define CMD_EDIT_SCROLLLINEDOWN         2060
#define CMD_EDIT_SCROLLLINEUP           2061
#define CMD_EDIT_SCROLLPAGEDOWN         2062
#define CMD_EDIT_SCROLLPAGEUP           2063
#define CMD_EDIT_SCROLLCOLUMNNEXT       2064
#define CMD_EDIT_SCROLLCOLUMNPREV       2065
#define CMD_EDIT_ENSURECARETCENTER      2066
#define CMD_EDIT_ENSURECARETVISIBLE     2067
#define CMD_EDIT_MAKENEXTSUPER          2068
#define CMD_EDIT_MAKENEXTSUB            2069
#define CMD_EDIT_ROWCHARNEXT            2070
#define CMD_EDIT_ROWCHARPREV            2071
#define CMD_EDIT_ROWLINEDOWN            2072
#define CMD_EDIT_ROWLINEUP              2073
#define CMD_EDIT_ROWLINEEND             2074
#define CMD_EDIT_ROWLINEHOME            2075
#define CMD_EDIT_ROWWORDNEXT            2076
#define CMD_EDIT_ROWWORDPREV            2077
#define CMD_EDIT_ROWWORDENDNEXT         2078
#define CMD_EDIT_ROWWORDENDPREV         2079
#define CMD_EDIT_PASTEFROMCLIPBOARDRING 2080
#define CMD_EDIT_CHARFROMABOVELINE      2081
#define CMD_EDIT_CHARFROMBELOWLINE      2082
#define CMD_EDIT_TRANSPOSELINES         2083
#define CMD_EDIT_TRANSPOSECHARS         2084
#define CMD_EDIT_TRANSPOSEWORDS         2085
#define CMD_EDIT_SHOWABBREVIATIONDLG    2086
#define CMD_EDIT_MAKENEXTMACRON         2087
#define CMD_EDIT_MAKENEXTBREVE          2088
#define CMD_EDIT_MAKENEXTCARON          2089
#define CMD_EDIT_FIRSTCHAR              2090
#define CMD_EDIT_LASTCHAR               2091
#define CMD_EDIT_FIRSTCHAREXTEND        2092
#define CMD_EDIT_LASTCHAREXTEND         2093
#define CMD_EDIT_FIRSTCHARORLINEHOME    2094
#define CMD_EDIT_LASTCHARORLINEEND      2095
#define CMD_EDIT_FIRSTCHARORLINEHOMEEXTEND 2096
#define CMD_EDIT_LASTCHARORLINEENDEXTEND 2097
#define CMD_EDIT_NARROWTOSELECTION      2098
#define CMD_EDIT_WIDEN                  2099
#define CMD_EDIT_TOP                    2900
#define CMD_EDIT_ADVANCED               2901
#define CMD_EDIT_INSERTUNICODECTRLS     2902
#define CMD_EDIT_INSERTUNICODEWSS       2903
#define CMD_SEARCH_FIND                 3000
#define CMD_SEARCH_FINDNEXT             3001
#define CMD_SEARCH_FINDPREV             3002
#define CMD_SEARCH_REPLACEANDNEXT       3004
#define CMD_SEARCH_REPLACEALL           3005
#define CMD_SEARCH_BOOKMARKALL          3006
#define CMD_SEARCH_REVOKEMARK           3007
#define CMD_SEARCH_GOTOLINE             3008
#define CMD_SEARCH_TOGGLEBOOKMARK       3009
#define CMD_SEARCH_NEXTBOOKMARK         3010
#define CMD_SEARCH_PREVBOOKMARK         3011
#define CMD_SEARCH_CLEARBOOKMARKS       3012
#define CMD_SEARCH_MANAGEBOOKMARKS      3013
#define CMD_SEARCH_GOTOMATCHBRACKET     3014
#define CMD_SEARCH_EXTENDTOMATCHBRACKET 3015
#define CMD_SEARCH_INCREMENTALSEARCH    3016
#define CMD_SEARCH_INCREMENTALSEARCHR   3017
#define CMD_SEARCH_INCREMENTALSEARCHRF  3018
#define CMD_SEARCH_INCREMENTALSEARCHRR  3019
#define CMD_SEARCH_INCREMENTALSEARCHMF  3020
#define CMD_SEARCH_INCREMENTALSEARCHMR  3021
#define CMD_SEARCH_TOP                  3900
#define CMD_VIEW_TOOLBAR                4000
#define CMD_VIEW_STATUSBAR              4001
#define CMD_VIEW_WRAPNO                 4002
#define CMD_VIEW_WRAPBYSPECIFIEDWIDTH   4003
#define CMD_VIEW_WRAPBYWINDOWWIDTH      4004
#define CMD_VIEW_REFRESH                4005
#define CMD_VIEW_SPLITNS                4006
#define CMD_VIEW_NEXTBUFFER             4007
#define CMD_VIEW_PREVBUFFER             4008
#define CMD_VIEW_BUFFERBAR              4009
#define CMD_VIEW_TOPMOSTALWAYS          4010
#define CMD_VIEW_SPLITWE                4011
#define CMD_VIEW_UNSPLITACTIVE          4012
#define CMD_VIEW_UNSPLITOTHERS          4013
#define CMD_VIEW_NEXTPANE               4014
#define CMD_VIEW_PREVPANE               4015
#define CMD_VIEW_BUFFERLIST_START       4100
#define CMD_VIEW_BUFFERLIST_END         4800
#define CMD_VIEW_TOP                    4900
#define CMD_VIEW_BUFFERS                4901
#define CMD_MACRO_RECORD                5000
#define CMD_MACRO_PLAY                  5001
#define CMD_MACRO_STOP                  5002
#define CMD_MACRO_ABORT                 5003
#define CMD_MACRO_PAUSERESTART          5004
#define CMD_MACRO_SAVEAS                5005
#define CMD_MACRO_LIST                  5006
#define CMD_MACRO_INTERRUPT             5007
#define CMD_MACRO_TOP                   5900
#define CMD_MACRO_SCRIPTS               5901
#define CMD_TOOL_COMMONOPTION           6000
#define CMD_TOOL_DOCTYPEOPTION          6001
#define CMD_TOOL_FONT                   6002
#define CMD_TOOL_EXECUTE                6003
#define CMD_TOOL_EXECUTECOMMAND         6004
#define CMD_TOOL_TOP                    6900
#define CMD_TOOL_APPDOCTYPES            6901
#define CMD_HELP_ABOUT                  7000
#define CMD_HELP_TOP                    7900
#define CMD_SPECIAL_ILLEGAL2STROKE      9000
#define CMD_SPECIAL_WAITFOR2NDKEYS      9001
#define CMD_SPECIAL_DISPATCHCHARINPUT   9002
#define COMMAND_END                     10000
#define CMD_FILE_MRULIST_START          11000
#define CMD_FILE_MRULIST_END            11100
#define CMD_FILE_DOCTYPELIST_START      11100
#define CMD_FILE_DOCTYPELIST_END        11200
#define CMD_TOOL_DOCTYPELIST_START      11200
#define CMD_TOOL_DOCTYPELIST_END        11300
#define CMD_EDIT_PLUGINLIST_START       11300
#define CMD_EDIT_PLUGINLIST_END         11500
#define MSG_FILE_IS_DIRTY               20000
#define MSG_ASK_REOPEN                  20001
#define MSG_ASK_REOPEN_IN_DIRTY         20002
#define MSG_FILE_HAS_BEEN_MODIFIED_BY_OTHER 20003
#define MSG_TEXT_NOT_FOUND              20004
#define MSG_REPLACE_SUCCEEDED           20005
#define MSG_FAILED_TO_LOAD_REGEXP_ENGINE 20006
#define MSG_REGEXP_PATTERN_SYNTAX_ERROR 20007
#define MSG_EXE_NOT_REGISTERED          20008
#define MSG_FAILED_TO_RUN_EXE           20009
#define MSG_FAILED_TO_LOAD              20010
#define MSG_MACRO_RECORDING             20011
#define MSG_DEBUGGING                   20012
#define MSG_INSERT_MODE                 20013
#define MSG_OVERTYPE_MODE               20014
#define MSG_DEFAULT_OPEN_FILE_FILTER    20015
#define MSG_READONLY_TITLE              20016
#define MSG_CARET_POSITION              20017
#define MSG_ISEARCH_PROMPT              20018
#define MSG_ISEARCH_NOT_FOUND_PROMPT    20019
#define MSG_FAILED_TO_OPERATE_FILE      20020
#define MSG_REOPENED_AS_READONLY        20021
#define MSG_FAILED_TO_REOPEN            20022
#define MSG_FILE_ACCESS_DENIED          20023
#define MSG_CODEPAGE_IS_NOT_INSTALLED   20024
#define MSG_UNKNOWN_ERROR               20025
#define MSG_OPENED_AS_READONLY          20026
#define MSG_FAILED_TO_DETECT_CODEPAGE   20027
#define MSG_FOUND_ILLEGAL_CHARACTER     20028
#define MSG_TOO_LARGE_FILE              20029
#define MSG_FILE_NOT_FOUND              20030
#define MSG_FAILED_TO_SEND_TO_MAILER    20031
#define MSG_FAILED_TO_PARSE_XML         20032
#define MSG_CANNOT_START_OUTLINE_PARSE  20033
#define MSG_FAILED_TO_LOAD_PLUGIN       20034
#define MSG_ILLEGAL_CODEPAGE            20035
#define MSG_FAILED_TO_RESOLVE_SHORTCUT  20036
#define MSG_ILLEGAL_SCRIPT_LANGUAGE_NAME 20037
#define MSG_FAILED_TO_LOAD_SAX_PARSER   20038
#define MSG_FAILED_TO_OPEN_MACRO_SCRIPT 20039
#define MSG_UNCONVERTABLE_UCS_CHAR      20040
#define MSG_INDICATE_CAN_EXPAND_ABBREV  20041
#define MSG_ISEARCH_TEXT_IS_EMPTY       20042
#define MSG_MATCH_CASE                  20043
#define MSG_IGNORE_ASCII_CASE           20044
#define MSG_CASEFOLDING_SIMPLE          20045
#define MSG_CASEFOLDING_FULL            20046
#define MSG_RISEARCH_PROMPT             20047
#define MSG_RISEARCH_NOT_FOUND_PROMPT   20048
#define MSG_RISEARCH_TEXT_IS_EMPTY      20049
#define MSG_LINE_NUMBER_RANGE           20050
#define MSG_CONFLICTED_ABBREVIATION     20051
#define MSG_MATCH_BRACKET_OUT_OF_VIEW   20052
#define MSG_REGEXP_RUNTIME_ERROR        20053
#define MSG_LOADING_FILE                20054
#define MSG_WAITING_FOR_2ND_KEYS        20055
#define MSG_ILLEGAL_2STROKE_COMBINATION 20056
#define MSG_ISEARCH_BAD_REGEXP          20057
#define MSG_RISEARCH_BAD_REGEXP         20058
#define MSG_LITERAL_SEARCH              20059
#define MSG_REGEXP_SEARCH               20060
#define MSG_MIGEMO_SEARCH               20061
#define MSG_UNCONVERTABLE_NATIVE_CHAR   20062
#define MSG_FAILED_TO_LOCK_FILE         20063
#define MSG_FAILED_TO_WRITE_FOR_FULLDISK 20064
#define MSG_FAILED_TO_WRITE_FOR_READONLY 20065
#define MSG_UNSUPPORTED_OS_VERSION      20066
#define MSG_UNCHANGE_BREAK_TYPE         20067
#define MSG_BUFFERBAR_CAPTION           20068
#define MSG_ABBREVIATION                20069
#define MSG_EXPANDED_ABBREVIATION       20070
#define MSG_LINE                        20071
#define MSG_POSITION                    20072
#define MSG_SELECTALL                   20073
#define MSG_UNSELECT_ALL                20074
#define MSG_SELECT_DIRECTORY            20075
#define MSG_FILE_OPERATION              20076
#define MSG_RENAME_FILE                 20077
#define MSG_COPY_FILE                   20078
#define MSG_MOVE_FILE                   20079
#define MSG_INVOKABLE_LINK_POPUP        20080
#define MSG_NARROWING                   20081
#define MSG_DEFAULT_UNTITLED_BUFFER     20082
#define MSG_SAVE_FILE_FILTER            20083
#define MSG_FILE_IS_USED_BY_OTHER_PROCESS	20084
#define MSG_BAD_REGEX_PATTERN_START		20085

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        159
#define _APS_NEXT_COMMAND_VALUE         40048
#define _APS_NEXT_CONTROL_VALUE         1308
#define _APS_NEXT_SYMED_VALUE           104
#endif
#endif
